==> haskell-xml-hamlet-0.4.1-48-i686.pkg.tar.xz: usr/share/haskell/register/haskell-xml-hamlet.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xml-hamlet
version: 0.4.1
id: xml-hamlet-0.4.1-Bh32bTaCjI8JRJ5Z3eslkl
key: xml-hamlet-0.4.1-Bh32bTaCjI8JRJ5Z3eslkl
license: BSD3
maintainer: michael@snoyman.com
homepage: http://www.yesodweb.com/
synopsis: Hamlet-style quasiquoter for XML content
description:
    Hamlet-style quasiquoter for XML content
category: Text
author: Michael Snoyman
exposed: True
indefinite: False
exposed-modules:
    Text.Hamlet.XML
hidden-modules: Text.Hamlet.XMLParse
abi: 7269bb93c5395a102bad38eae9d9c21a
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/xml-hamlet-0.4.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/xml-hamlet-0.4.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/xml-hamlet-0.4.1
hs-libraries: HSxml-hamlet-0.4.1-Bh32bTaCjI8JRJ5Z3eslkl
depends:
    base-4.10.0.0 shakespeare-2.0.14-80JAimk0BGVHInw7Ob1gtk
    xml-conduit-1.6.0-BWoyzWzm2lWEOl7Dzk57oG
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz template-haskell-2.12.0.0
    parsec-3.1.11-5WCVqUZr6ypLPXtYWYsMnh containers-0.5.10.2
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             shakespeare-2.0.14-80JAimk0BGVHInw7Ob1gtk=d12dae2378f00fd1e1d4bacf864e25ef
             xml-conduit-1.6.0-BWoyzWzm2lWEOl7Dzk57oG=f75d67ad0439bcc94bf75dda8c0736b1
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             template-haskell-2.12.0.0=84fec1eab31df12231c00a687a39fdc3
             parsec-3.1.11-5WCVqUZr6ypLPXtYWYsMnh=da03630454c215de5f3965e7b0f0e5da
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
haddock-interfaces: /usr/share/doc/haskell-xml-hamlet/html/xml-hamlet.haddock
haddock-html: /usr/share/doc/haskell-xml-hamlet/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-xml-hamlet-0.4.1-49-i686.pkg.tar.xz: usr/share/haskell/register/haskell-xml-hamlet.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xml-hamlet
version: 0.4.1
id: xml-hamlet-0.4.1-6KwjlOh9kO281XKrJ5dhAs
key: xml-hamlet-0.4.1-6KwjlOh9kO281XKrJ5dhAs
license: BSD3
maintainer: michael@snoyman.com
homepage: http://www.yesodweb.com/
synopsis: Hamlet-style quasiquoter for XML content
description:
    Hamlet-style quasiquoter for XML content
category: Text
author: Michael Snoyman
exposed: True
indefinite: False
exposed-modules:
    Text.Hamlet.XML
hidden-modules: Text.Hamlet.XMLParse
abi: e9f164ed74716124b367ee409b9d5559
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/xml-hamlet-0.4.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/xml-hamlet-0.4.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/xml-hamlet-0.4.1
hs-libraries: HSxml-hamlet-0.4.1-6KwjlOh9kO281XKrJ5dhAs
depends:
    base-4.10.0.0 shakespeare-2.0.14-2RhgkLt2BZ2FcVRcUHxGbk
    xml-conduit-1.6.0-BWoyzWzm2lWEOl7Dzk57oG
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz template-haskell-2.12.0.0
    parsec-3.1.11-5WCVqUZr6ypLPXtYWYsMnh containers-0.5.10.2
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             shakespeare-2.0.14-2RhgkLt2BZ2FcVRcUHxGbk=c1be0c7e3aef06708629b91f4c947edf
             xml-conduit-1.6.0-BWoyzWzm2lWEOl7Dzk57oG=f75d67ad0439bcc94bf75dda8c0736b1
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             template-haskell-2.12.0.0=84fec1eab31df12231c00a687a39fdc3
             parsec-3.1.11-5WCVqUZr6ypLPXtYWYsMnh=da03630454c215de5f3965e7b0f0e5da
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
haddock-interfaces: /usr/share/doc/haskell-xml-hamlet/html/xml-hamlet.haddock
haddock-html: /usr/share/doc/haskell-xml-hamlet/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
